/*
 * Copyright (C) 2010 Eiichiro Uchiumi. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.eiichiro.monophony;

import java.lang.annotation.Annotation;
import java.lang.reflect.Type;
import java.util.List;

/**
 * {@code Request} abstracts Web contexts to invoke Web endpoint method.
 * Web endpoint method parameters are constructed from this object.<br>
 * <br>
 * You can implement this interface yourself to construct Web endpoint method 
 * parameter from the content type that Monophony doesn't support. You can 
 * specify your {@code Request} implementation type by overriding 
 * {@code Settings#requestType(String)} in your custom {@code Settings}.
 * 
 * @see Settings
 * @author <a href="mailto:eiichiro@eiichiro.org">Eiichiro Uchiumi</a>
 */
public interface Request {

	/**
	 * Constructs the Web endpoint method parameter value as the specified 
	 * {@code Type} and source.
	 * This method is invoked if the Web endpoint method parameter is annotated 
	 * with {@code @Source}-annotated annotation (e.g. {@code @Query}, {@code @Body}, 
	 * {@code @Header}, {@code @Cookie}, {@code @Session} and {@code @Application})
	 * The implementation class must return <code>null</code>, if it cannot 
	 * construct the value from these parameter.
	 * 
	 * @param type The type of Web endpoint method parameter.
	 * @param sources The source list from which Web endpoint method parameter 
	 * is constructed.
	 * @return Web endpoint method parameter.
	 */
	public Parameter get(Type type, List<Annotation> sources);
	
}
