/*
 * Copyright (C) 2010 Eiichiro Uchiumi. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0
 *     
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.eiichiro.monophony;

/**
 * {@code Response} abstracts Web endpoint invocation response. If Web endpoint 
 * method does not return {@code Response} type object, Monophony instantiates 
 * the {@code Response} implementation class corresponding to the MIME media 
 * type that the Web endpoint method should return by getting the class from 
 * {@code Settings}.<br>
 * <br>
 * You can implement this interface yourself to construct Web endpoint method 
 * invocation response corresponding to the content type that Monophony doesn't 
 * support. You can specify your {@code Response} implementation type by 
 * overriding {@code Settings#responseType(String)} in your custom 
 * {@code Settings}.
 * 
 * @see Settings
 * @author <a href="mailto:eiichiro@eiichiro.org">Eiichiro Uchiumi</a>
 */
public interface Response {

	/**
	 * Sets HTTP response status code.
	 * 
	 * @param status HTTP response status code.
	 * @return
	 */
	public Response status(int status);
	
	/**
	 * Sets MIME media type.
	 * 
	 * @param mediaType MIME media type to be included in "Content-Type" HTTP 
	 * response header.
	 * @return {@code Response}.
	 */
	public Response mediaType(String mediaType);

	/**
	 * Outputs the response representation to the client.
	 * 
	 * @param context Web context.
	 */
	public void out(WebContext context);
	
}
